==> phplist-2.10.5p0.tgz: lists/admin/lan/pt-br/common.php <==
<?php

# file with common texts for translation

$lan = array(
  'logout' => 'Desconectar',
  'Main Page' => 'P&aacute;gina Principal ',
  'user' => 'Usu&aacute;rio',
  'error' => 'Erro',
  'version' => 'vers&aacute;o',
  'powered by' => 'produzido com',
  'fatalerror' => 'Erro Fatal',
  'warning' => 'Aten&ccedil;&atilde;o',
  'information' => 'Informa&ccedil;&atilde;o',
  'help' => 'ajuda',
  'about' => 'sobre',
  'lists' => 'listas',
  'send a message' => 'Enviar uma mensagem',
  'users' => 'usu&aacute;rios',
  'manage users' => 'gerenciamento de usu&aacute;rios',
  'messages' => 'mensagens',
  'statistics' => 'estat&iacute;sticas',
  'process queue' => 'fila de processamento',
  'configure' => 'configurar',
  'Subscribe Pages' => 'P&aacute;ginas de Inscri&ccedil;&atilde;o',
  'Send a prepared message' => 'Enviar uma mensagem pronta',
  'Prepare a message' => 'Elaborar uma mensagem',
  'Templates' => 'Modelos',
  'View Bounces' => 'Ver Emails com Problemas',
  'Process Bounces' => 'Processar Emails com Problemas',
  'Eventlog' => 'Registro de Eventos',
  'Sunday' => 'Domingo',
  'Monday' => 'Segunda-feira',
  'Tuesday' => 'Ter&ccedil;a-feira',
  'Wednesday' => 'Quarta-feira',
  'Thursday' => 'Quinta-feira',
  'Friday' => 'Sexta-feira',
  'Saturday' => 'S&aacute;bado',
  'January' => 'Janeiro',
  'February' => 'Fevereiro',
  'March' => 'Mar&ccedil;o',
  'April' => 'Abril',
  'May' => 'Maio',
  'June' => 'Junho',
  'July' => 'Julho',
  'August' => 'Agosto',
  'September' => 'Setembro',
  'October' => 'Outubro',
  'November' => 'Novembro',
  'December' => 'Dezembro',
  'Jan' => 'Jan',
  'Feb' => 'Fev',
  'Mar' => 'Mar',
  'Apr' => 'Abr',
  'May' => 'Mai',
  'Jun' => 'Jun',
  'Jul' => 'Jul',
  'Aug' => 'Ago',
  'Sep' => 'Set',
  'Oct' => 'Out',
  'Nov' => 'Nov',
  'Dec' => 'Dec',
  # from sendemaillib
  'sendingtextonlyto' => 'Enviando texto somente para',
  'sendingmessage' => 'Enviando Mensagem',
  'withsubject' => 'com assunto',
  'to' => 'para',
  'admininitfailure' => 'Falha ao iniciar a Autentica&ccedil;&atilde;o do Admin',
  'yourpassword' => 'Sua senha para o phplist',
  'yourpasswordis' => 'Sua senha &eacute;',
  'passwordsent' => 'Sua senha foi enviada para o seus email',
  'cannotsendpassword' => 'N&atilde;o foi poss&iacute;vel enviar a senha',
  'ipchanged' => 'Seu endere&ccedil;o IP mudou. Por quest&otilde;es de seguran&ccedil;a, conecte de novo',
  'goodbye' => 'at&eacute; logo',
  'goodmorning' => 'bom dia',
  'goodafternoon' => 'boa tarde',
  'goodevening' => 'boa noite',
  'safemodewarning' => 'No modo de seguran&ccedil;a, nem todas as caracter&iacutesticas funcionar&aacuteo corretamente',
  'magicquoteswarning' => 'As coisas funcionar&atilde;o melhor quando o PHP magic_quotes_gpc = <b>ativado</b>',
  'magicruntimewarning' => 'As coisas funcionar&atilde;o melhor quando o PHP magic_quotes_runtime = desativado',
  'noxml' => 'Voc&ecirc; est&aacute; tentando usar o RSS, mas o XML n&atilde;o est&aacute; inclu&iacute;do no seu PHP',
  'warnopenbasedir' => 'as restri&ccedil;&otilde;es do open_basedir est&atilde;o ativas, que pode ser a causa dos pr&oacute;ximos aviso de aten&ccedil;&atilde;o',
  'warnattachmentrepository' => 'o resposit&oacute;rio de anexos n&atilde;o existe ou n&atilde;o &eacute; grav&acute;vel',
  'nofpdf' => 'Voc&ecirc; est&aacute; tentando usar o suporte PDF sem ter carregado o FPDF',
  'warnpageroot' => 'A p&aacute;gina ra&iacute;z de sua configura&ccedil;&atilde;o n&atilde;o corresponde ao atual endere&ccedil;o<br/>Verifique o seu arquivo de configura&ccedil;&atilde;o.',
  'pagenotfoundinplugin' => 'Desculpe, esta p&aacute;gina n&atilde;o foi encontrada no plugin',
  'notimplemented' => 'Desculpe, ainda n&atilde;o implementado',
  'noaccess' => 'Voc&ecirc; n&atilde;o tem permiss&otilde;es suficientes para acessar esta p&aacute;gina',
  'nohelpavailable' => 'Desculpe, a ajuda para este assunto ainda n&atilde;o est&aacute; dispon&iacute;vel: ',
  'closewindow' => 'Fechar esta janela',
  'success' => 'completado com sucesso',
  'failed' => 'falhou',
  'default login is' => 'Usu&aacute;rio padr&atilde;o &eacute;',
  'with password' => 'com senha',
  'name' => 'Nome',
  'password' => 'Senha',
  'enter' => 'Entrar',
  'forgot password' => 'Esqueceu a sua senha?',
  'enter your email' => 'Entre com o seu email',
  'send password' => 'Enviar Senha',
  'An image exists on the server, check this box to keep the existing one' => 'Uma imagem existe neste servidor, marque esta caixa para manter a j&acute; existente',
  'View Image' => 'Exibir Imagem',
  'Upload new image' => 'Enviar nova imagem',
  'textline' => 'linha de texto',
  'textarea' => '&aacute;rea de texto',
  'date' => 'data',
  'checkbox' => 'caixa de sele&ccedil;&atilde;o',
  'radio' => 'bot&atilde;o de radio',
  'select' => 'selecionar',
  'checkboxgroup' => 'grupo de caixa de sele&ccedil;&atilde;o',
  'unnamed list' => 'Lista sem nome',
  'unknown' => 'Desconhecido',
  'very little time' => 'pouqu&iacute;ssimo tempo',
  'A process for this page is already running and it was still alive' => 'Um processo para esta p&aacute;gina est&aacute; j&aacute; sendo executado neste momento',
  'seconds ago' => 'segundos atr&aacute;s',
  'We have been waiting too long, I guess the other process is still going ok' => 'J&aacute; estou esperando faz tempo, acho que outros processos est&atildo; sendo executados corretametne',
  'Sleeping for 20 seconds, aborting will quit' => 'Esperar  20 segundos, cancelando voc&ecirc; sair&aacute;',
  'No Image was found' => 'Nenhuma Imagem foi encontrada',
  'messages' => 'Mensagens',
  'bounces' => 'emails com problema',
  'bounce' => 'email com problema',
  'msg' => 'msg', # as in short for message
  'time' => 'hora',
  'sent' => 'enviado',
  'text' => 'texto',
  'html' => 'html',
);

?>

==> phplist-2.10.17p2.tgz: lists/admin/lan/pt-br/common.php <==
<?php

# file with common texts for translation

$lan = array(
  'logout' => 'Desconectar',
  'Main Page' => 'P&aacute;gina Principal ',
  'user' => 'Usu&aacute;rio',
  'error' => 'Erro',
  'version' => 'vers&aacute;o',
  'powered by' => 'produzido com',
  'fatalerror' => 'Erro Fatal',
  'warning' => 'Aten&ccedil;&atilde;o',
  'information' => 'Informa&ccedil;&atilde;o',
  'help' => 'ajuda',
  'about' => 'sobre',
  'lists' => 'listas',
  'send a message' => 'Enviar uma mensagem',
  'users' => 'usu&aacute;rios',
  'manage users' => 'gerenciamento de usu&aacute;rios',
  'messages' => 'mensagens',
  'statistics' => 'estat&iacute;sticas',
  'process queue' => 'fila de processamento',
  'configure' => 'configurar',
  'Subscribe Pages' => 'P&aacute;ginas de Inscri&ccedil;&atilde;o',
  'Send a prepared message' => 'Enviar uma mensagem compartilhada',
  'Prepare a message' => 'Elaborar uma mensagem',
  'Templates' => 'Modelos',
  'View Bounces' => 'Ver Emails de Erro',
  'Process Bounces' => 'Processar Emails de Erro',
  'Eventlog' => 'Registro de Eventos',
  'Sunday' => 'Domingo',
  'Monday' => 'Segunda-feira',
  'Tuesday' => 'Ter&ccedil;a-feira',
  'Wednesday' => 'Quarta-feira',
  'Thursday' => 'Quinta-feira',
  'Friday' => 'Sexta-feira',
  'Saturday' => 'S&aacute;bado',
  'January' => 'Janeiro',
  'February' => 'Fevereiro',
  'March' => 'Mar&ccedil;o',
  'April' => 'Abril',
  'May' => 'Maio',
  'June' => 'Junho',
  'July' => 'Julho',
  'August' => 'Agosto',
  'September' => 'Setembro',
  'October' => 'Outubro',
  'November' => 'Novembro',
  'December' => 'Dezembro',
  'Jan' => 'Jan',
  'Feb' => 'Fev',
  'Mar' => 'Mar',
  'Apr' => 'Abr',
  'May' => 'Mai',
  'Jun' => 'Jun',
  'Jul' => 'Jul',
  'Aug' => 'Ago',
  'Sep' => 'Set',
  'Oct' => 'Out',
  'Nov' => 'Nov',
  'Dec' => 'Dez',
  # from sendemaillib
  'sendingtextonlyto' => 'Enviando texto somente para',
  'sendingmessage' => 'Enviando Mensagem',
  'withsubject' => 'com assunto',
  'to' => 'para',
  'admininitfailure' => 'Falha ao iniciar a Autentica&ccedil;&atilde;o do Admin',
  'yourpassword' => 'Sua senha para o phplist',
  'yourpasswordis' => 'Sua senha &eacute;',
  'passwordsent' => 'Sua senha foi enviada para o seus email',
  'cannotsendpassword' => 'N&atilde;o foi poss&iacute;vel enviar a senha',
  'ipchanged' => 'Seu endere&ccedil;o IP mudou. Por quest&otilde;es de seguran&ccedil;a, conecte de novo',
  'goodbye' => 'at&eacute; logo',
  'goodmorning' => 'bom dia',
  'goodafternoon' => 'boa tarde',
  'goodevening' => 'boa noite',
  'safemodewarning' => 'No modo de seguran&ccedil;a, nem todas as caracter&iacutesticas funcionar&aacuteo corretamente',
  'magicquoteswarning' => 'As coisas funcionar&atilde;o melhor quando o PHP magic_quotes_gpc = <b>ativado</b>',
  'magicruntimewarning' => 'As coisas funcionar&atilde;o melhor quando o PHP magic_quotes_runtime = desativado',
  'noxml' => 'Voc&ecirc; est&aacute; tentando usar o RSS, mas o XML n&atilde;o est&aacute; inclu&iacute;do no seu PHP',
  'warnopenbasedir' => 'as restri&ccedil;&otilde;es do open_basedir est&atilde;o ativas, que pode ser a causa dos pr&oacute;ximos aviso de aten&ccedil;&atilde;o',
  'warnattachmentrepository' => 'o resposit&oacute;rio de anexos n&atilde;o existe ou n&atilde;o &eacute; grav&acute;vel',
  'nofpdf' => 'Voc&ecirc; est&aacute; tentando usar o suporte PDF sem ter carregado o FPDF',
  'warnpageroot' => 'A p&aacute;gina ra&iacute;z de sua configura&ccedil;&atilde;o n&atilde;o corresponde ao atual endere&ccedil;o<br/>Verifique o seu arquivo de configura&ccedil;&atilde;o.',
  'pagenotfoundinplugin' => 'Desculpe, esta p&aacute;gina n&atilde;o foi encontrada no plugin',
  'notimplemented' => 'Desculpe, ainda n&atilde;o implementado',
  'noaccess' => 'Voc&ecirc; n&atilde;o tem permiss&otilde;es suficientes para acessar esta p&aacute;gina',
  'nohelpavailable' => 'Desculpe, a ajuda para este assunto ainda n&atilde;o est&aacute; dispon&iacute;vel: ',
  'closewindow' => 'Fechar esta janela',
  'success' => 'completado com sucesso',
  'failed' => 'falhou',
  'default login is' => 'Usu&aacute;rio padr&atilde;o &eacute;',
  'with password' => 'com senha',
  'name' => 'Nome',
  'password' => 'Senha',
  'enter' => 'Entrar',
  'forgot password' => 'Esqueceu a sua senha?',
  'enter your email' => 'Entre com o seu email',
  'send password' => 'Enviar Senha',
  'An image exists on the server, check this box to keep the existing one' => 'Para manter as imagens acima, selecione a caixa',
  'View Image' => 'Exibir Imagem',
  'Upload new image' => 'Enviar nova imagem',
  'textline' => 'linha de texto',
  'textarea' => '&aacute;rea de texto',
  'date' => 'data',
  'checkbox' => 'caixa de sele&ccedil;&atilde;o',
  'radio' => 'bot&atilde;o de radio',
  'select' => 'selecionar',
  'checkboxgroup' => 'grupo de caixa de sele&ccedil;&atilde;o',
  'unnamed list' => 'Lista sem nome',
  'unknown' => 'Desconhecido',
  'very little time' => 'pouqu&iacute;ssimo tempo',
  'A process for this page is already running and it was still alive' => 'Um processo para esta p&aacute;gina est&aacute; j&aacute; sendo executado neste momento',
  'seconds ago' => 'segundos atr&aacute;s',
  'We have been waiting too long, I guess the other process is still going ok' => 'J&aacute; estou esperando faz tempo, acho que outros processos est&atildo; sendo executados corretametne',
  'Sleeping for 20 seconds, aborting will quit' => 'Esperar  20 segundos, cancelando voc&ecirc; sair&aacute;',
  'No Image was found' => 'Nenhuma Imagem foi encontrada',
  'messages' => 'Mensagens',
  'bounces' => 'emails de erro',
  'bounce' => 'email de erro',
  'msg' => 'msg', # as in short for message
  'time' => 'hora',
  'sent' => 'enviado',
  'text' => 'texto',
  'html' => 'html',
  'manage bounces' => 'gerenciar mails de erro',
);

?>
